/* Copyright 2008 Red Hat, Inc.
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _KUDZU_VIRTIO_H_
#define _KUDZU_VIRTIO_H_

#include "device.h"

/* Virtio devices appear on the PCI bus with
 * qumranet's vendor ID (0x1af4) and with
 * device IDs in the range 0x1000-0x103f
 */
#define IS_VIRTIO_DEVICE(v, d) ((v) == 0x1af4 && (d) >= 0x1000 && (d) <= 0x103f)

#define VIRTIO_ID_NET   1
#define VIRTIO_ID_BLOCK 2

struct virtioDevice {
    /* common fields */
    struct device *next;	/* next device in list */
    int index;
    enum deviceClass type;	/* type */
    enum deviceBus bus;		/* bus it's attached to */
    char * device;		/* device file associated with it */
    char * driver;		/* driver to load, if any */
    char * desc;		/* a description */
    int detached;
    void * classprivate;
    /* virtio-specific fields */
    struct virtioDevice *(*newDevice) (struct virtioDevice *dev);
    void (*freeDevice) (struct virtioDevice *dev);
    void (*writeDevice) (FILE *file, struct virtioDevice *dev);
    int (*compareDevice) (struct virtioDevice *dev1, struct virtioDevice *dev2);
};

struct virtioDevice *virtioNewDevice(struct virtioDevice *dev);
struct device *virtioProbe(enum deviceClass probeClass, int probeFlags,
			   struct device *devlist);

#endif
